# Use the Local Workflow

Plan, implement, and ship code locally.

<!-- TODO: This document is a skeleton. Fill in the sections below. -->

## Overview

<!-- TODO: Summary of the local plan-driven workflow -->

## Step 1: Start a Claude Code Session

<!-- TODO: claude command -->

## Step 2: Enter Plan Mode

<!-- TODO: How to enter plan mode -->

## Step 3: Develop Your Plan

<!-- TODO: Tips for effective planning -->

## Step 4: Save the Plan

<!-- TODO: What happens when you exit plan mode -->

## Step 5: Implement the Plan

<!-- TODO: erk implement <issue-number> -->

## Step 6: Submit the PR

<!-- TODO: erk pr submit or /erk:pr-submit -->

## Step 7: Address Review Feedback

<!-- TODO: /erk:pr-address workflow -->

## Step 8: Land the PR

<!-- TODO: erk pr land -->

## Quick Iteration

<!-- TODO: /quick-submit for rapid commits -->

## See Also

- [Your First Plan](../tutorials/first-plan.md) - Tutorial walkthrough
- [The Workflow](../topics/the-workflow.md) - Conceptual overview
